ElementModel class

Constructors

ElementModel(String? key, Rect? bounds, Offset? offset, Type runtimeType, {Element? element})
ElementModel.empty()
factory

Properties

bounds ↔ Rect?
getter/setter pair
element ↔ Element?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
getter/setter pair
offset ↔ Offset?
getter/setter pair
runtimeType ↔ Type
A representation of the runtime type of the object.
getter/setter pairoverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited